hotspot/test/compiler/membars/DekkerTest.java
changeset 40059 c2304140ed64
parent 35594 cc13089c6327
child 40062 3b21b3295f19
--- a/hotspot/test/compiler/membars/DekkerTest.java	Tue Jul 12 08:42:46 2016 +0000
+++ b/hotspot/test/compiler/membars/DekkerTest.java	Tue Jul 12 18:24:48 2016 +0300
@@ -25,14 +25,22 @@
  * @test
  * @bug 8007898
  * @summary Incorrect optimization of Memory Barriers in Matcher::post_store_load_barrier().
  * @run main/othervm -Xbatch -XX:+IgnoreUnrecognizedVMOptions -XX:-TieredCompilation -XX:CICompilerCount=1 -XX:+StressGCM -XX:+StressLCM DekkerTest
  * @run main/othervm -Xbatch -XX:+IgnoreUnrecognizedVMOptions -XX:-TieredCompilation -XX:CICompilerCount=1 -XX:+StressGCM -XX:+StressLCM DekkerTest
  * @run main/othervm -Xbatch -XX:+IgnoreUnrecognizedVMOptions -XX:-TieredCompilation -XX:CICompilerCount=1 -XX:+StressGCM -XX:+StressLCM DekkerTest
  * @author Martin Doerr martin DOT doerr AT sap DOT com
  *
  * Run 3 times since the failure is intermittent.
  */
 
+package compiler.membars;
+
 public class DekkerTest {
 
     /*
@@ -25,14 +25,22 @@
  * @bug 8007898
  * @summary Incorrect optimization of Memory Barriers in Matcher::post_store_load_barrier().
- * @run main/othervm -Xbatch -XX:+IgnoreUnrecognizedVMOptions -XX:-TieredCompilation -XX:CICompilerCount=1 -XX:+StressGCM -XX:+StressLCM DekkerTest
- * @run main/othervm -Xbatch -XX:+IgnoreUnrecognizedVMOptions -XX:-TieredCompilation -XX:CICompilerCount=1 -XX:+StressGCM -XX:+StressLCM DekkerTest
- * @run main/othervm -Xbatch -XX:+IgnoreUnrecognizedVMOptions -XX:-TieredCompilation -XX:CICompilerCount=1 -XX:+StressGCM -XX:+StressLCM DekkerTest
+ * @run main/othervm -Xbatch -XX:+IgnoreUnrecognizedVMOptions -XX:-TieredCompilation
+ *                   -XX:CICompilerCount=1 -XX:+StressGCM -XX:+StressLCM
+ *                   compiler.membars.DekkerTest
+ * @run main/othervm -Xbatch -XX:+IgnoreUnrecognizedVMOptions -XX:-TieredCompilation
+ *                   -XX:CICompilerCount=1 -XX:+StressGCM -XX:+StressLCM
+ *                   compiler.membars.DekkerTest
+ * @run main/othervm -Xbatch -XX:+IgnoreUnrecognizedVMOptions -XX:-TieredCompilation
+ *                   -XX:CICompilerCount=1 -XX:+StressGCM -XX:+StressLCM
+ *                   compiler.membars.DekkerTest
  * @author Martin Doerr martin DOT doerr AT sap DOT com
  *